"use strict";

var _vitest = require("vitest");
var _react = _interopRequireDefault(require("react"));
var _react2 = require("@testing-library/react");
var _index = _interopRequireDefault(require("../index"));
var _AvatarInformation = _interopRequireDefault(require("../AvatarInformation"));
var _AvatarGroup = _interopRequireDefault(require("../AvatarGroup"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
var classList = ["gui-avatar--highlighted", "gui-avatar--offline", "gui-avatar--size-sm", "gui-avatar--bordered", "gui-avatar--animated", "gui-avatar--has-colour", "gui-avatar--is-locked"];
(0, _vitest.describe)("Avatar", function () {
  (0, _vitest.it)("adds the modifer classes", function () {
    var _render = (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
        initials: "AE",
        name: "Angus Edwardson"
      })),
      rerender = _render.rerender;
    var avatar = _react2.screen.getAllByRole("figure")[0];
    classList.map(function (modifierClass) {
      (0, _vitest.expect)(avatar.classList.contains(modifierClass)).toBe(false);
    });
    rerender( /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "AE",
      name: "Angus Edwardson",
      isHighlighted: true,
      isOffline: true,
      smallSize: true,
      bordered: true,
      animate: true,
      colour: "red",
      locked: true
    }));
    avatar = _react2.screen.getAllByRole("figure")[0];
    classList.map(function (modifierClass) {
      (0, _vitest.expect)(avatar.classList.contains(modifierClass)).toBeTruthy();
    });
  });
  (0, _vitest.it)("renders the initials if there is no url provided", function () {
    (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "AE",
      name: "Angus Edwardson"
    }));
    _react2.screen.getByText("AE");
  });
  (0, _vitest.it)("renders the avatar image", function () {
    (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "AE",
      name: "Angus Edwardson",
      url: "url/to/avatar"
    }));
    _react2.screen.getByRole("img");
  });
});
(0, _vitest.describe)("AvatarInformation", function () {
  (0, _vitest.it)("Renders the stuff", function () {
    var name = "Waffle McWaffleson";
    var email = "waffles@waffletown.com";
    var _render2 = (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_AvatarInformation["default"], {
        name: name,
        email: email
      })),
      findByText = _render2.findByText;
    (0, _vitest.expect)(findByText(name));
    (0, _vitest.expect)(findByText(email));
  });
});
(0, _vitest.describe)("AvatarGroup", function () {
  (0, _vitest.it)("Renders a group of Avatars", function () {
    (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_AvatarGroup["default"], {
      maximum: 4
    }, /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "MR",
      name: "Mike Rotch"
    }), /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "HJ",
      name: "Hugh Jass"
    }), /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "FD",
      name: "Fedra Droid"
    }), /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "KM",
      name: "Kann Schemll"
    })));
    var avatars = _react2.screen.queryAllByRole("figure");
    (0, _vitest.expect)(avatars.length).toEqual(4);
    var firstParent = avatars[0].parentNode;
    (0, _vitest.expect)(firstParent.style.zIndex).toEqual("4");
    var lastParent = avatars[3].parentNode;
    (0, _vitest.expect)(lastParent.style.zIndex).toEqual("1");
  });
  (0, _vitest.it)("Respects the maximum setting and puts the rest in a dropdown", function () {
    (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_AvatarGroup["default"], {
      maximum: 1
    }, /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "MR",
      name: "Mike Rotch"
    }), /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "HJ",
      name: "Hugh Jass"
    }), /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "FD",
      name: "Fedra Droid"
    }), /*#__PURE__*/_react["default"].createElement(_index["default"], {
      initials: "KM",
      name: "Kann Schemll"
    })));
    var avatars = _react2.screen.queryAllByRole("figure");
    (0, _vitest.expect)(avatars.length).toEqual(5);
    (0, _vitest.expect)(_react2.screen.getByText("+3"));
    (0, _vitest.expect)(_react2.screen.getAllByRole("button"));
  });
});
//# sourceMappingURL=Avatar.spec.js.map